#!/usr/bin/python3

from openai import OpenAI


class ChatDeepInfra:
    def __init__(self, base_url: str, api_key: str, model: str):
        self.client = OpenAI(
            api_key=api_key,
            base_url=base_url,
        )
        self.model = model
        self.system_prompt = "You are a helpful assistant."
        self.history = []  # guarda mensagens no formato OpenAI

    # --------------------------------------------------
    # Define ou altera o system prompt
    # --------------------------------------------------
    def set_system_prompt(self, system_prompt: str):
        self.system_prompt = system_prompt

    # --------------------------------------------------
    # Pergunta SEM memória (equivalente ao seu código original)
    # --------------------------------------------------
    def ask_once(self, user_msg: str, stream: bool = False) -> str:
        messages = [
            {"role": "system", "content": self.system_prompt},
            {"role": "user", "content": user_msg},
        ]

        response = self.client.chat.completions.create(
            model=self.model,
            messages=messages,
            stream=stream,
        )

        return self._handle_response(response, stream)

    # --------------------------------------------------
    # Pergunta COM memória (usa histórico interno)
    # --------------------------------------------------
    def chat(self, user_msg: str, stream: bool = False, last_turns: int | None = None) -> str:
        messages = [{"role": "system", "content": self.system_prompt}]

        if last_turns is None:
            selected_history = self.history
        else:
            selected_history = self.history[-2 * last_turns:]

        messages.extend(selected_history)
        messages.append({"role": "user", "content": user_msg})

        response = self.client.chat.completions.create(
            model=self.model,
            messages=messages,
            stream=stream,
        )

        output = self._handle_response(response, stream)
        
        # salva no histórico
        self.history.append({"role": "user", "content": user_msg})
        self.history.append({"role": "assistant", "content": output})

        return output

    # --------------------------------------------------
    # Limpa histórico
    # --------------------------------------------------
    def clear_history(self):
        self.history = []

    def get_history(self):
        return self.history.copy()
    
    # --------------------------------------------------
    # Função interna para tratar streaming ou não
    # --------------------------------------------------
    def _handle_response(self, response, stream: bool) -> str:
        if stream:
            output = ""
            for event in response:
                if event.choices[0].finish_reason:
                    continue
                delta = event.choices[0].delta
                if hasattr(delta, "content") and delta.content:
                    print(delta.content, end="", flush=True)
                    output += delta.content
            print()
            return output
        else:
            return response.choices[0].message.content


if __name__ == "__main__":
    api_key = input("Digite sua API key: ")
    base_url = "https://api.deepinfra.com/v1/openai"
    model = "meta-llama/Meta-Llama-3.1-70B-Instruct"

    cdi = ChatDeepInfra(base_url, api_key, model)

    cdi.set_system_prompt("Você é um assistente acadêmico. Mas vocé não tem papo furado é eficiente quando da respostas. Sua personalidade é espartana e estoica.")

    # Pergunta sem memória
    print("\n--- Pergunta isolada ---")
    
    prompt="Qual é o valor do numero aureo"
    print(">>",prompt)
    print("<<",cdi.ask_once(prompt))

    # Chat com memória
    print("\n--- Chat com memória ---")
    
    prompt="Vou te fazer uma pergunta esteja atento."
    print(">>",prompt)
    print("<<",cdi.chat(prompt))
    
    prompt="quanto é 2+2?"
    print(">>",prompt)
    print("<<",cdi.chat(prompt))

    # Limpar histórico
    cdi.clear_history()



#!/usr/bin/python3

from openai import OpenAI

def speech_file_transcript_deepinfra(   base_url,
                                        api_key,
                                        model,
                                        audio_path,
                                        language=None):
    '''
    https://deepinfra.com/mistralai/Voxtral-Mini-3B-2507/api?example=openai-speech-python
    
    audio_path: The audio file object to transcribe. Supported formats are flac, mp3, mp4, mpeg, mpga, m4a, ogg, wav, and webm.
    '''
    client = OpenAI(api_key=api_key, base_url=base_url)

    try:
        with open(audio_path, "rb") as audio_file:
            if language:
                transcript = client.audio.transcriptions.create(
                    model=model,
                    file=audio_file,
                    language=language
                )
            else:
                transcript = client.audio.transcriptions.create(
                    model=model,
                    file=audio_file
                )
        # Retorna sempre string (mesmo que vazia)
        return transcript.text or ""
    except Exception as e:
        print(f"[speech_file_transcript_deepinfra] Error: {e}")
        raise  # permite que a função superior capture

def speech_file_translate_deepinfra(base_url, api_key, model, audio_path):
    """
    Traduz um arquivo de áudio para inglês usando DeepInfra/OpenAI API.
    
    audio_path: caminho para o arquivo de áudio (mp3, wav, ogg, m4a...)
    """
    client = OpenAI(api_key=api_key, base_url=base_url)

    try:
        with open(audio_path, "rb") as audio_file:
            translation = client.audio.translations.create(
                model=model,
                file=audio_file
            )
        return translation.text or ""
    except Exception as e:
        print(f"[speech_file_translate_deepinfra] Error: {e}")
        raise
        
if __name__ == "__main__":
    # from deep_consultation import consult_with_deepchat
    api_key = input("Digite sua API key: ")
    base_url = "https://api.deepinfra.com/v1/openai"
    audio_path = "/home/fernando/Downloads/audio.mp3"

    model = "mistralai/Voxtral-Mini-3B-2507" # only transcript
    transcription = speech_file_transcript_deepinfra(base_url, api_key, model, audio_path)
    print("\nResposta do modelo:\n")
    print(transcription)
        
    model = "openai/whisper-large-v3" # only whisper translate and transcript
    translation = speech_file_translate_deepinfra(base_url, api_key, model, audio_path)
    print("\nResposta do modelo:\n")
    print(translation)
